Learn R Programming

MandalaR (version 0.1.0)

pelipse: creates a dataframe containing the points for the elipse mandala

Description

Function to build point for the elipse base

Usage

pelipse(theta, a, b, k, n)

Value

Returns a dataframe with the original points plus the respective rotations of these points.

Arguments

theta

is a vector length 2 with start angle and end angle

a

is one of the parameters of the curves; for the ellipse is the radius on the x axis

b

is one of the parameters of the curves; for the ellipse is the radius on the y axis

k

is a vector of length 1 with angles in degree to rotate the point (x,y)

n

is a number of points

Author

Luciane Ferreira Alcoforado

Examples

Run this code
theta = c(0,2*pi) #half turn angle
a = 1
b=2
k = 90
n=20
pelipse(theta, a, b, k, n)

Run the code above in your browser using DataLab