Learn R Programming

MandalaR (version 0.1.0)

plimacon: creates a dataframe containing the points for the limacon mandala

Description

Function to build a limacon

Usage

plimacon(theta, raio, k, n)

Value

Returns a dataframe with the original points plus the respective rotations of these points.

Arguments

theta

is a vector length 2 with start angle and end angle

raio

is a vector length 1 with radius value

k

is a vector of length 1 with angles in degree to rotate the point (x,y)

n

is a number of points

Author

Luciane Ferreira Alcoforado

Examples

Run this code
theta = c(0,2*pi)
k=45
raio = 1
n=20
plimacon(theta, raio, k, n)

Run the code above in your browser using DataLab