powered by
Function to build point for the elipse base
pelipse(theta, a, b, k, n)
Returns a dataframe with the original points plus the respective rotations of these points.
is a vector length 2 with start angle and end angle
is one of the parameters of the curves; for the ellipse is the radius on the x axis
is one of the parameters of the curves; for the ellipse is the radius on the y axis
is a vector of length 1 with angles in degree to rotate the point (x,y)
is a number of points
Luciane Ferreira Alcoforado
theta = c(0,2*pi) #half turn angle a = 1 b=2 k = 90 n=20 pelipse(theta, a, b, k, n)
Run the code above in your browser using DataLab